aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/includes/functions_install.php
diff options
context:
space:
mode:
Diffstat (limited to 'phpBB/includes/functions_install.php')
-rw-r--r--phpBB/includes/functions_install.php12
1 files changed, 6 insertions, 6 deletions
diff --git a/phpBB/includes/functions_install.php b/phpBB/includes/functions_install.php
index 7fa299548d..a5889224a1 100644
--- a/phpBB/includes/functions_install.php
+++ b/phpBB/includes/functions_install.php
@@ -181,7 +181,7 @@ function get_available_dbms($dbms = false, $return_unavailable = false, $only_20
function dbms_select($default = '', $only_20x_options = false)
{
global $lang;
-
+
$available_dbms = get_available_dbms(false, false, $only_20x_options);
$dbms_options = '';
foreach ($available_dbms as $dbms_name => $details)
@@ -402,10 +402,10 @@ function connect_check_db($error_connect, &$error, $dbms_details, $table_prefix,
}
else
{
- $sql = "SELECT FIRST 0 char_length('')
- FROM RDB\$DATABASE";
+ $sql = 'SELECT 1 FROM RDB$DATABASE
+ WHERE BIN_AND(10, 1) = 0';
$result = $db->sql_query($sql);
- if (!$result) // This can only fail if char_length is not defined
+ if (!$result) // This can only fail if BIN_AND is not defined
{
$error[] = $lang['INST_ERR_DB_NO_FIREBIRD'];
}
@@ -446,7 +446,7 @@ function connect_check_db($error_connect, &$error, $dbms_details, $table_prefix,
unset($final);
}
break;
-
+
case 'oracle':
if ($unicode_check)
{
@@ -468,7 +468,7 @@ function connect_check_db($error_connect, &$error, $dbms_details, $table_prefix,
}
}
break;
-
+
case 'postgres':
if ($unicode_check)
{